pub enum TableEvent<'a> {
Schema(&'a [PublicColumn]),
Row(&'a [Cell]),
End,
}Expand description
One event of TableRows/1.
Variants
Schema(&'a [PublicColumn])
Exactly one, first.
Row(&'a [Cell])
As many as there are rows, each exactly as wide as the schema.
End
Exactly one, last, and only after the source validated to its end.